@@ -333,7 +333,7 @@ cb_thumbnail_ready(XfdesktopThumbnailer *thumbnailer,
                                    COL_THUMBNAIL, thumb_file, -1);
 
                 pdata = g_new0(PreviewData, 1);
-                pdata->model = g_object_ref(G_OBJECT(model));
+                pdata->model = GTK_TREE_MODEL(g_object_ref(G_OBJECT(model)));
                 pdata->iter = gtk_tree_iter_copy(&iter);
                 pdata->pix = NULL;
 
@@ -363,7 +363,7 @@ xfdesktop_settings_queue_preview(GtkTreeModel *model,
         /* Thumbnailing not possible, add it to the queue to be loaded manually */
         PreviewData *pdata;
         pdata = g_new0(PreviewData, 1);
-        pdata->model = g_object_ref(G_OBJECT(model));
+        pdata->model = GTK_TREE_MODEL(g_object_ref(G_OBJECT(model)));
         pdata->iter = gtk_tree_iter_copy(iter);
 
         XF_DEBUG("Thumbnailing failed, adding %s manually.", filename);
@@ -418,7 +418,7 @@ setup_special_icon_list(GtkBuilder *gxml,
     } icons[] = {
         { N_("Home"), "user-home", "gnome-fs-desktop",
           DESKTOP_ICONS_SHOW_HOME, TRUE },
-        { N_("Filesystem"), "drive-harddisk", "gnome-dev-harddisk",
+        { N_("File System"), "drive-harddisk", "gnome-dev-harddisk",
           DESKTOP_ICONS_SHOW_FILESYSTEM, TRUE },
         { N_("Trash"), "user-trash", "gnome-fs-trash-empty",
           DESKTOP_ICONS_SHOW_TRASH, TRUE },
@@ -2166,7 +2166,7 @@ main(int argc, char **argv)
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, VERSION, xfce_version_string());
-        g_print("%s\n", "Copyright (c) 2004-2015");
+        g_print("%s\n", "Copyright (c) 2004-2020");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
